Forms — django-sphinxdoc 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-sphinxdoc 1.2.0 documentation »
- API-Reference »

# Forms

Forms for the sphinxdoc app.

class `sphinxdoc.forms.` `ProjectSearchForm`(*args, **kwargs)

  Custom search form for Haystack.

  It narrows the search query set to instances of `Document` that belong to the current `Project`.

### Navigation

- index
- modules |
- next |
- previous |
- django-sphinxdoc 1.2.0 documentation »
- API-Reference »